@@ -3,5 +3,5 @@ import pandas as pd
 import os
 data_dir = os.path.dirname(os.path.abspath(other.__file__))
 
-def read(self):
+def read(data_dir):
 	return pd.read_excel(data_dir+'/rules.xlsx',index_col=0)
\ No newline at end of file
